import setuptools

setuptools.setup(
    name="potato_communicate",
    version="1.0.1",
    author="thtTNT",
    description="跨平台通讯框架PotatoCommunicate的python端",
    packages=setuptools.find_packages(),
    python_requires=">=3.8"
)
